03-paths: Metrics for Path Preservation

path PreservationR Documentation

Metrics for Path Preservation

Description

Utility functions for computing vectors of row-by-row means, variances, and t-statistics.

Usage

LengthDistortion(M1, M2)
SegmentVariance(M1, M2)
Curvature(M1, M2)
SpatialSimilarity(M1, M2)

Arguments

M1

a data matrix decribing the path in the original space.

M2

a data matrix describing the (same) path after dimension reduction.

Value

Each of the four functions returns a real number representing the log ratio of the scores betweent he two path representation.

Author(s)

Kevin R. Coombes <krc@silicovore.com>


Preservation documentation built on May 12, 2026, 3:02 p.m.