| path Preservation | R Documentation |
Utility functions for computing vectors of row-by-row means, variances, and t-statistics.
LengthDistortion(M1, M2)
SegmentVariance(M1, M2)
Curvature(M1, M2)
SpatialSimilarity(M1, M2)
M1 |
a data matrix decribing the path in the original space. |
M2 |
a data matrix describing the (same) path after dimension reduction. |
Each of the four functions returns a real number representing the log ratio of the scores betweent he two path representation.
Kevin R. Coombes <krc@silicovore.com>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.